/*

Copyright (C) 2009 Jaroslav Barton <djaara@djaara.net>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#ifndef FINGERMANAGERWINDOW_H_
#define FINGERMANAGERWINDOW_H_

#include <KSeparator>
#include <QCheckBox>
#include <QWidget>
#include <QLabel>
#include <QButtonGroup>
#include <QComboBox>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <KConfig>
#include <KCModule>
#include <QGroupBox>
#include <KAboutData>
#include <KUser>

#include "FMDbusConn.h"

#define MAX_FINGERS 10

class KPushButton;

typedef struct {
	int x;
	int y;
} pos;

class FingerManagerWindow : public KCModule 
{
	Q_OBJECT

	public:
		FingerManagerWindow(QWidget *parent, const QVariantList &);
		~FingerManagerWindow();

	private slots:
		void fingerSelectedSlot(int finger);
		void deviceChangedSlot(int idx);
		void deleteAllSlot();
	
    private:
		void		initComponents();
		void		retranslate();
		void		loadConfig(KConfig *config);
		void		processFingers(const QStringList &fngrs);
		void 		enableAllFingers(bool enabled);
		QCheckBox  	*createCheckBox(int idx, int x, int y);

		KAboutData	*m_aboutData;
		KConfig		*m_config;

		QGroupBox	*m_box;
		QLabel		*m_handsLabel;
		QButtonGroup *m_btng;
		QWidget		*m_handsPanel;
		QCheckBox	*m_fingers[MAX_FINGERS];
		QLabel		*m_deviceLabel;
		QComboBox	*m_devices;
		KSeparator	*m_separator;

		QHBoxLayout	*handsLayout;
		QHBoxLayout	*devicesLayout;
		QVBoxLayout	*mainPanelLayout;
		QVBoxLayout	*mainLayout;
		
        KPushButton	*m_deleteAllBtn;
		FMDbusConn	*m_dbc;
		QString		m_loginName;
};

#endif /*FINGERMANAGERWINDOW_H_*/
